- :warning: This code is new and should not yet be considered secure for production use!
Tx5
- tx5 -
- The main holochain tx5 webrtc networking crate integrating the other code in this monorepo.
Tx5 Support Crates
- tx5-core -
- Core types used in other tx5 crates.
- tx5-online -
- Network online connectivity status events.
- tx5-go-pion-turn -
- Rust process wrapper around tx5-go-pion-turn executable.
- tx5-go-pion-sys -
- Low level rust bindings to the go pion webrtc library.
- tx5-go-pion -
- Higher level rust bindings to the go pion webrtc library.
- tx5-signal -
- Holochain webrtc signal client.
- tx5-signal-srv -
- Holochain webrtc signal server.
- tx5-demo -
- Demo showing off tx5 p2p connectivity.
tx5-signal-srv
Holochain webrtc signal server.
The tx5-signal-srv executable
tx5-signal-srv --help
Holochain Webrtc Signal Server
Usage: tx5-signal-srv [OPTIONS]
Options:
-i, --init
Initialize a new tx5-signal-srv.json configuration file (as specified
by --config). Will abort if it already exists
--run-with-init-if-needed
Run the signal server, generating a config file if one does not
already exist. Exclusive with "init" option
-c, --config <CONFIG>
Configuration file to use for running the tx5-signal-srv. Defaults to
`$user_config_dir_path$/tx5-signal-srv.json`
-h, --help
Print help
-V, --version
Print version
Modules
- deps
- Re-exported dependencies.
Structs
- Config
- Tx5-signal-srv config.
- Error
- Tx5 core error type.
- Id
- Tx5 32-byte identifier.
- Opt
- Tx5 signal server execution configuration.
- SrvHnd
- A handle to the server instance. This has no functionality except that when it is dropped, the server will shut down.
Enums
- Config
PerOpt - Result type from the config_per_opt function.
Traits
- Error
Ext - Extension trait to extract a name from a Tx5 core error type.
Functions
- config_
per_ opt - If Opt specifies “init”, write an example configuration file, otherwise read and parse the config file.
- exec_
tx5_ signal_ srv - The main entrypoint tx5-signal-server logic task.
- read_
config - Read and parse a tx5-signal-srv.json configuration file.
- write_
example_ config - Encode and write an example tx5-signal-srv.json configuration file.